@@ -10,12 +10,13 @@
 #******************************************************************************************
 #******************************************************************************************
 
-linarpr <- function(Y, id=NULL, weight=NULL, Y_thres=NULL, wght_thres=NULL,
-                 sort=NULL, Dom=NULL, period=NULL, dataset = NULL, percentage=60, 
-                 order_quant=50, var_name="lin_arpr") {
+linarpr <- function(Y, id = NULL, weight = NULL, Y_thres = NULL,
+                    wght_thres = NULL, sort = NULL, Dom = NULL, 
+                    period = NULL, dataset = NULL, percentage = 60, 
+                    order_quant = 50, var_name = "lin_arpr") {
  
    ## initializations
-   if (min(dim(data.table(var_name))==1)!=1) {
+   if (min(dim(data.table(var_name)) == 1) != 1) {
        stop("'var_name' must have defined one name of the linearized variable")}
 
    # check 'p'
@@ -30,29 +31,29 @@ linarpr <- function(Y, id=NULL, weight=NULL, Y_thres=NULL, wght_thres=NULL,
 
    if(!is.null(dataset)) {
        dataset <- data.table(dataset)
-       if (checker(Y, dataset, "Y"))  Y <- dataset[, Y, with=FALSE] 
+       if (checker(Y, dataset, "Y"))  Y <- dataset[, Y, with = FALSE] 
 
        if(!is.null(id)) {
-          if (checker(id, dataset, "id")) id <- dataset[, id, with=FALSE]}
+          if (checker(id, dataset, "id")) id <- dataset[, id, with = FALSE]}
 
        if(!is.null(weight)) {
-           if (checker(weight, dataset, "weight")) weight <- dataset[, weight, with=FALSE] }
+           if (checker(weight, dataset, "weight")) weight <- dataset[, weight, with = FALSE] }
 
        if(!is.null(Y_thres)) {
-           if (checker(Y_thres, dataset, "Y_thres")) Y_thres <- dataset[, Y_thres, with=FALSE] }
+           if (checker(Y_thres, dataset, "Y_thres")) Y_thres <- dataset[, Y_thres, with = FALSE] }
      
        if(!is.null(wght_thres)) {
-           if (checker(wght_thres, dataset, "wght_thres")) wght_thres <- dataset[, wght_thres, with=FALSE] }
+           if (checker(wght_thres, dataset, "wght_thres")) wght_thres <- dataset[, wght_thres, with = FALSE] }
 
        if(!is.null(sort)) {
-           if (checker(sort, dataset, "sort")) sort <- dataset[, sort, with=FALSE] }
+           if (checker(sort, dataset, "sort")) sort <- dataset[, sort, with = FALSE] }
 
        if (!is.null(period)) {
             if (min(period %in% names(dataset))!=1) stop("'period' does not exist in 'dataset'!")
-            if (min(period %in% names(dataset))==1) period <- dataset[, period, with=FALSE]}
+            if (min(period %in% names(dataset))==1) period <- dataset[, period, with = FALSE]}
 
        if (!is.null(Dom)) {
-            if (checker(Dom, dataset, "Dom")) Dom <- data.table(dataset[, Dom, with=FALSE])}
+            if (checker(Dom, dataset, "Dom")) Dom <- data.table(dataset[, Dom, with = FALSE])}
     }
 
    # check vectors
@@ -60,7 +61,7 @@ linarpr <- function(Y, id=NULL, weight=NULL, Y_thres=NULL, wght_thres=NULL,
    Y <- data.frame(Y)
    n <- nrow(Y)
    if (ncol(Y) != 1) stop("'Y' must be a vector or 1 column data.frame, matrix, data.table")
-   Y <- Y[,1]
+   Y <- Y[, 1]
    if(!is.numeric(Y)) stop("'Y' must be numeric")
    if (any(is.na(Y))) stop("'Y' has missing values")
 
@@ -78,7 +79,7 @@ linarpr <- function(Y, id=NULL, weight=NULL, Y_thres=NULL, wght_thres=NULL,
    if (!is.null(Y_thres)) {
         if (nrow(Y_thres) != n) stop("'Y_thres' must be the same length as 'Y'")
         if (ncol(Y_thres) != 1) stop("'Y_thres' must be a vector or 1 column data.frame, matrix, data.table")
-        Y_thres <- Y_thres[,1]
+        Y_thres <- Y_thres[, 1]
         if(!is.numeric(Y_thres)) stop("'Y_thres' must be numeric")
         if (any(is.na(Y_thres))) stop("'Y_thres' has missing values") 
      } 
@@ -88,7 +89,7 @@ linarpr <- function(Y, id=NULL, weight=NULL, Y_thres=NULL, wght_thres=NULL,
    wght_thres <- data.frame(wght_thres)
    if (nrow(wght_thres) != n) stop("'wght_thres' must be the same length as 'Y'")
    if (ncol(wght_thres) != 1) stop("'wght_thres' must be a vector or 1 column data.frame, matrix, data.table")
-   wght_thres <- wght_thres[,1]
+   wght_thres <- wght_thres[, 1]
    if (!is.numeric(wght_thres)) stop("'wght_thres' must be numeric")
    if (any(is.na(wght_thres))) stop("'wght_thres' has missing values") 
     
@@ -107,17 +108,17 @@ linarpr <- function(Y, id=NULL, weight=NULL, Y_thres=NULL, wght_thres=NULL,
                  stop("'period' are duplicate column names: ", 
                       paste(names(period)[duplicated(names(period))], collapse = ","))
        if (nrow(period) != n) stop("'period' must be the same length as 'Y'")
-       period[, (names(period)):=lapply(.SD, as.character)]
+       period[, (names(period)) := lapply(.SD, as.character)]
        if(any(is.na(period))) stop("'period' has missing values")
    }   
    
    # id
-   if (is.null(id)) id <- 1:n
+   if (is.null(id)) id <- 1 : n
    id <- data.table(id)
    if (any(is.na(id))) stop("'id' has missing values")
    if (ncol(id) != 1) stop("'id' must be 1 column data.frame, matrix, data.table")
    if (nrow(id) != n) stop("'id' must be the same length as 'Y'")
-   if (is.null(names(id))||(names(id)=="id")) setnames(id,names(id),"ID")
+   if (is.null(names(id)) | (names(id) == "id")) setnames(id, names(id), "ID")
    if (is.null(period)){ if (any(duplicated(id))) stop("'id' are duplicate values") 
                        } else {
                           id1 <- data.table(period, id)
@@ -132,7 +133,7 @@ linarpr <- function(Y, id=NULL, weight=NULL, Y_thres=NULL, wght_thres=NULL,
                       paste(names(Dom)[duplicated(names(Dom))], collapse = ","))
              if (is.null(names(Dom))) stop("'Dom' must have column names")
              if (nrow(Dom) != n) stop("'Dom' must be the same length as 'Y'")
-             Dom[, (names(Dom)):=lapply(.SD, as.character)] 
+             Dom[, (names(Dom)) := lapply(.SD, as.character)] 
              if (any(is.na(Dom))) stop("'Dom' has missing values")
              if (any(grepl("__", names(Dom)))) stop("'Dom' is not allowed column names with '__'")
        }
@@ -142,22 +143,23 @@ linarpr <- function(Y, id=NULL, weight=NULL, Y_thres=NULL, wght_thres=NULL,
     period_agg <- period1 <- NULL
     if (!is.null(period)) { period1 <- copy(period)
                             period_agg <- data.table(unique(period))
-                        } else period1 <- data.table(ind=ind0)
+                        } else period1 <- data.table(ind = ind0)
     period1_agg <- data.table(unique(period1))
 
     # ARPR by domain (if requested)
     quantile <- incPercentile(Y = Y_thres,
-                               weights = wght_thres,
-                               sort = sort, Dom = NULL,
-                               period = period,
-                               k = order_quant,
-                               dataset = NULL)
+                              weights = wght_thres,
+                              sort = sort, Dom = NULL,
+                              period = period,
+                              k = order_quant,
+                              dataset = NULL)
+
     quantile <- data.table(quantile)
     setnames(quantile, names(quantile)[ncol(quantile)], "quantile")
-    if (ncol(quantile)>1) setkeyv(quantile, head(names(quantile), -1))
+    if (ncol(quantile) > 1) setkeyv(quantile, head(names(quantile), -1))
     threshold <- copy(quantile)
-    threshold[, threshold:=p/100 * quantile]
-    threshold[, quantile:=NULL]
+    threshold[, threshold := p / 100 * quantile]
+    threshold[, quantile := NULL]
 
     arpr_id <- id
     if (!is.null(period)) arpr_id <- data.table(arpr_id, period)
@@ -168,61 +170,61 @@ linarpr <- function(Y, id=NULL, weight=NULL, Y_thres=NULL, wght_thres=NULL,
           
         arpr_v <- c()
         arpr_m <- copy(arpr_id)
-        for(i in 1:nrow(Dom_agg)) {
+        for(i in 1 : nrow(Dom_agg)) {
               g <- c(var_name, paste(names(Dom), as.matrix(Dom_agg[i,]), sep = "."))
               var_nams <- do.call(paste, as.list(c(g, sep="__")))
               ind <- as.integer(rowSums(Dom == Dom_agg[i,][ind0,]) == ncol(Dom))
 
-              arprl <- lapply(1:nrow(period1_agg), function(j) {
+              arprl <- lapply(1 : nrow(period1_agg), function(j) {
                                if (!is.null(period)) { 
                                        rown <- cbind(period_agg[j], Dom_agg[i])
                                        setkeyv(rown, names(rown))
                                        rown2 <- copy(rown)
-                                       rown <- merge(rown, quantile, all.x=TRUE)
+                                       rown <- merge(rown, quantile, all.x = TRUE)
                                      } else {rown <- quantile
                                              rown2 <- Dom_agg[i] }
 
                                indj <- (rowSums(period1 == period1_agg[j,][ind0,]) == ncol(period1))
       
-                               arpr_l <- arprlinCalc(Y1=Y[indj],
-                                                     ids=arpr_id[indj],
-                                                     wght1=weight[indj],
-                                                     indicator=ind[indj],
-                                                     Y_thresh=Y_thres[indj],
-                                                     wght_thresh=wght_thres[indj],
-                                                     percent=p,
-                                                     order_quants=order_quant,
-                                                     quant_val=rown[["quantile"]])
-                      list(arpr=data.table(rown2, arpr=arpr_l$rate_val_pr), lin=arpr_l$lin)
+                               arpr_l <- arprlinCalc(Y1 = Y[indj],
+                                                     ids = arpr_id[indj],
+                                                     wght1 = weight[indj],
+                                                     indicator = ind[indj],
+                                                     Y_thresh = Y_thres[indj],
+                                                     wght_thresh = wght_thres[indj],
+                                                     percent = p,
+                                                     order_quants = order_quant,
+                                                     quant_val = rown[["quantile"]])
+                      list(arpr = data.table(rown2, arpr = arpr_l$rate_val_pr), lin = arpr_l$lin)
                       })
                  arprs <- rbindlist(lapply(arprl, function(x) x[[1]]))
                  arprlin <- rbindlist(lapply(arprl, function(x) x[[2]]))
 
                  setnames(arprlin, names(arprlin), c(names(arpr_id), var_nams))
-                 arpr_m <- merge(arpr_m, arprlin, all.x=TRUE, by=names(arpr_id))
+                 arpr_m <- merge(arpr_m, arprlin, all.x = TRUE, by = names(arpr_id))
                  arpr_v <- rbind(arpr_v, arprs) 
            }
      } else { arprl <- lapply(1:nrow(period1_agg), function(j) {
                            if (!is.null(period)) { 
                                          rown <- period_agg[j]
-                                         rown <- merge(rown, quantile, all.x=TRUE,
-                                                       by=names(rown))
+                                         rown <- merge(rown, quantile, all.x = TRUE,
+                                                       by = names(rown))
                                        } else rown <- quantile
                            ind2 <- (rowSums(period1 == period1_agg[j,][ind0,]) == ncol(period1))
       
-                           arpr_l <- arprlinCalc(Y1=Y[ind2],
-                                                 ids=arpr_id[ind2],
-                                                 wght1=weight[ind2],
-                                                 indicator=ind0[ind2],
-                                                 Y_thresh=Y_thres[ind2],
-                                                 wght_thresh=wght_thres[ind2],
-                                                 percent=p,
-                                                 order_quants=order_quant,
-                                                 quant_val=rown[["quantile"]]) 
+                           arpr_l <- arprlinCalc(Y1 = Y[ind2],
+                                                 ids = arpr_id[ind2],
+                                                 wght1 = weight[ind2],
+                                                 indicator = ind0[ind2],
+                                                 Y_thresh = Y_thres[ind2],
+                                                 wght_thresh = wght_thres[ind2],
+                                                 percent = p,
+                                                 order_quants = order_quant,
+                                                 quant_val = rown[["quantile"]]) 
                           if (!is.null(period)) { 
-                                   arprs <- data.table(period_agg[j], arpr=arpr_l$rate_val_pr)
-                             } else arprs <- data.table(arpr=arpr_l$rate_val_pr)
-                          list(arpr=arprs, lin=arpr_l$lin)
+                                   arprs <- data.table(period_agg[j], arpr = arpr_l$rate_val_pr)
+                             } else arprs <- data.table(arpr = arpr_l$rate_val_pr)
+                          list(arpr = arprs, lin = arpr_l$lin)
                        })
                arpr_v <- rbindlist(lapply(arprl, function(x) x[[1]]))
                arpr_m <- rbindlist(lapply(arprl, function(x) x[[2]]))
@@ -230,7 +232,7 @@ linarpr <- function(Y, id=NULL, weight=NULL, Y_thres=NULL, wght_thres=NULL,
             } 
      arpr_m[is.na(arpr_m)] <- 0
      setkeyv(arpr_m, names(arpr_id))
-     return(list(quantile=quantile, threshold=threshold, value=arpr_v, lin=arpr_m))
+     return(list(quantile = quantile, threshold = threshold, value = arpr_v, lin = arpr_m))
 }
 
 
@@ -243,37 +245,37 @@ arprlinCalc <- function(Y1, ids, wght1, indicator, Y_thresh, wght_thresh, percen
     wght2 <- wght_thresh
   
     wt <- indicator * wght1
-    thres_val <- percent/100 * quant_val
+    thres_val <- percent / 100 * quant_val
     N0 <- sum(wght2)   # Estimated whole population size 
     N <- sum(wt)       # Estimated (sub)population size
 
-    poor <- (Y1<=thres_val)
-    rate_val <- sum(wt*poor)/N  # Estimated poverty rate */
-    rate_val_pr <- 100*rate_val
+    poor <- (Y1 <= thres_val)
+    rate_val <- sum(wt * poor) / N  # Estimated poverty rate */
+    rate_val_pr <- 100 * rate_val
 
-    h <- sqrt((sum(wght2*inc2*inc2)-sum(wght2*inc2)*sum(wght2*inc2)/sum(wght2))/sum(wght2))/exp(0.2*log(sum(wght2))) 
+    h <- sqrt((sum(wght2 * inc2 * inc2) - sum(wght2 * inc2) * sum(wght2 * inc2) / sum(wght2)) / sum(wght2)) / exp(0.2 * log(sum(wght2))) 
     # h=S/N^(1/5)
 
     #---- 1. Linearization of the poverty threshold ----
 
-    u1 <- (quant_val-inc2)/h
-    vect_f1 <- exp(-(u1^2)/2)/sqrt(2*pi)
-    f_quant1 <- sum(vect_f1*wght2)/(N0*h)   # Estimate of F'(quantile)
+    u1 <- (quant_val - inc2) / h
+    vect_f1 <- exp(-(u1^2)/2) / sqrt(2 * pi)
+    f_quant1 <- sum(vect_f1 * wght2)/(N0 * h)   # Estimate of F'(quantile)
 
-    lin_thres <- -(percent/100)*(1/N0)*((inc2<=quant_val)-order_quants/100)/f_quant1  # Linearized variable
+    lin_thres <- - (percent / 100) * (1 / N0) * ((inc2 <= quant_val) - order_quants / 100) / f_quant1  # Linearized variable
 
     #---- 2. Linearization of the poverty rate -----
 
-    u2 <-   (thres_val-Y1)/h
-    vect_f2 <- exp(-(u2^2)/2)/sqrt(2*pi)
-    f_quant2 <- sum(vect_f2*wt)/(N*h)      # Estimate of F'(beta*quantile)
+    u2 <-   (thres_val - Y1) / h
+    vect_f2 <- exp(-(u2^2) / 2) / sqrt(2 * pi)
+    f_quant2 <- sum(vect_f2 * wt) / (N * h)      # Estimate of F'(beta*quantile)
 
  #****************************************************************************************
  #                       LINEARIZED VARIABLE OF THE POVERTY RATE (IN %)                  *
  #****************************************************************************************
-    lin <- 100*((1/N)*indicator*((Y1<=thres_val)-rate_val)+f_quant2*lin_thres)
+    lin <- 100 * ((1 / N) * indicator * ((Y1 <= thres_val) - rate_val) + f_quant2 * lin_thres)
 
-    lin_id <- data.table(ids,lin)
-    return(list(rate_val=rate_val, rate_val_pr=rate_val_pr, lin=lin_id))
+    lin_id <- data.table(ids, lin)
+    return(list(rate_val = rate_val, rate_val_pr = rate_val_pr, lin = lin_id))
 }
 
