@@ -10,13 +10,14 @@
 #*********************************************************************************************************
 #*********************************************************************************************************
 
-linrmpg <- function(Y, id=NULL, weight=NULL, sort=NULL, Dom=NULL,
-                    period=NULL, dataset = NULL, percentage=60, 
-                    order_quant=50, var_name="lin_rmpg") {
+linrmpg <- function(Y, id = NULL, weight = NULL, sort = NULL,
+                    Dom = NULL, period = NULL, dataset = NULL,
+                    percentage = 60, order_quant = 50,
+                    var_name = "lin_rmpg") {
  
    ## initializations
    
-   if (min(dim(as.data.frame(var_name))==1)!=1) {
+   if (min(dim(as.data.frame(var_name)) == 1) != 1) {
        stop("'var_name' must have defined name of the linearized variable")}
 
    # check 'p'
@@ -31,23 +32,23 @@ linrmpg <- function(Y, id=NULL, weight=NULL, sort=NULL, Dom=NULL,
 
    if (!is.null(dataset)) {
         dataset <- data.table(dataset)
-        if (checker(Y, dataset, "Y")) Y <- dataset[, Y, with=FALSE] 
+        if (checker(Y, dataset, "Y")) Y <- dataset[, Y, with = FALSE] 
 
         if (!is.null(id)) {
-             if (checker(id, dataset, "id")) id <- dataset[, id, with=FALSE] }
+             if (checker(id, dataset, "id")) id <- dataset[, id, with = FALSE] }
 
         if(!is.null(weight)) {
-            if (checker(weight, dataset, "weight")) weight <- dataset[, weight, with=FALSE] }
+            if (checker(weight, dataset, "weight")) weight <- dataset[, weight, with = FALSE] }
 
         if(!is.null(sort)) {
-            if (checker(sort, dataset, "sort")) sort <- dataset[, sort, with=FALSE] }
+            if (checker(sort, dataset, "sort")) sort <- dataset[, sort, with = FALSE] }
 
        if (!is.null(period)) {
-            if (min(period %in% names(dataset))!=1) stop("'period' does not exist in 'dataset'!")
-            if (min(period %in% names(dataset))==1) period <- dataset[, period, with=FALSE] }
+            if (min(period %in% names(dataset)) != 1) stop("'period' does not exist in 'dataset'!")
+            if (min(period %in% names(dataset)) == 1) period <- dataset[, period, with = FALSE] }
 
         if (!is.null(Dom)) {
-             if (checker(Dom, dataset, "Dom")) Dom <- dataset[, Dom, with=FALSE] }
+             if (checker(Dom, dataset, "Dom")) Dom <- dataset[, Dom, with = FALSE] }
       }
 
    # check vectors
@@ -55,7 +56,7 @@ linrmpg <- function(Y, id=NULL, weight=NULL, sort=NULL, Dom=NULL,
    Y <- data.frame(Y)
    n <- nrow(Y)                     
    if (ncol(Y) != 1) stop("'Y' must be a vector or 1 column data.frame, matrix, data.table")
-   Y <- Y[,1]
+   Y <- Y[, 1]
    if (!is.numeric(Y)) stop("'Y' must be numeric")
    if (any(is.na(Y))) stop("'Y' has missing values")
  
@@ -64,7 +65,7 @@ linrmpg <- function(Y, id=NULL, weight=NULL, sort=NULL, Dom=NULL,
    if (is.null(weight)) weight <- data.frame(rep.int(1, n))
    if (nrow(weight) != n) stop("'weight' must be the same length as 'Y'")
    if (ncol(weight) != 1) stop("'weight' must be a vector or 1 column data.frame, matrix, data.table")
-   weight <- weight[,1]
+   weight <- weight[, 1]
    if (!is.numeric(weight)) stop("'weight' must be numeric")
    if (any(is.na(weight))) stop("'weight' has missing values")
 
@@ -83,17 +84,17 @@ linrmpg <- function(Y, id=NULL, weight=NULL, sort=NULL, Dom=NULL,
                  stop("'period' are duplicate column names: ", 
                       paste(names(period)[duplicated(names(period))], collapse = ","))
        if (nrow(period) != n) stop("'period' must be th e same length as 'Y'")
-       period[, (names(period)):=lapply(.SD, as.character)]  
+       period[, (names(period)) := lapply(.SD, as.character)]  
        if(any(is.na(period))) stop("'period' has missing values")
    }   
 
    # id
-   if (is.null(id)) id <- 1:n
+   if (is.null(id)) id <- 1 : n
    id <- data.table(id)
    if (any(is.na(id))) stop("'id' has missing values")
    if (ncol(id) != 1) stop("'id' must be 1 column data.frame, matrix, data.table")
    if (nrow(id) != n) stop("'id' must be the same length as 'Y'")
-   if (is.null(names(id))||(names(id)=="id")) setnames(id,names(id),"ID")
+   if (is.null(names(id)) | (names(id)=="id")) setnames(id, names(id), "ID")
    if (is.null(period)){ if (any(duplicated(id))) stop("'id' are duplicate values") 
                        } else {
                           id1 <- data.table(period, id)
@@ -109,7 +110,7 @@ linrmpg <- function(Y, id=NULL, weight=NULL, sort=NULL, Dom=NULL,
                       paste(names(Dom)[duplicated(names(Dom))], collapse = ","))
              if (is.null(names(Dom))) stop("'Dom' must have column names")
              if (nrow(Dom) != n) stop("'Dom' must be the same length as 'Y'")
-             Dom[, (names(Dom)):=lapply(.SD, as.character)]  
+             Dom[, (names(Dom)) := lapply(.SD, as.character)]  
              if (any(is.na(Dom))) stop("'Dom' has missing values")
              if (any(grepl("__", names(Dom)))) stop("'Dom' is not allowed column names with '__'")
        }
@@ -124,17 +125,20 @@ linrmpg <- function(Y, id=NULL, weight=NULL, sort=NULL, Dom=NULL,
 
     # Relative median at-risk-of-poverty gap by domain (if requested)
 
-    quantile <- incPercentile(Y = Y, weights = weight,
-                              sort = sort, Dom = NULL,
+    quantile <- incPercentile(Y = Y, 
+                              weights = weight,
+                              sort = sort,
+                              Dom = NULL,
                               period = period,
                               k = order_quant,
                               dataset = NULL)
+
     quantile <- data.table(quantile)
     setnames(quantile, names(quantile)[ncol(quantile)], "quantile")
     if (ncol(quantile)>1) setkeyv(quantile, head(names(quantile), -1))
     threshold <- copy(quantile)
-    threshold[, threshold:=p/100 * quantile]
-    threshold[, quantile:=NULL]
+    threshold[, threshold := p / 100 * quantile]
+    threshold[, quantile := NULL]
    
     rmpgap_id <- id
     if (!is.null(period)) rmpgap_id <- data.table(period, rmpgap_id)
@@ -151,54 +155,57 @@ linrmpg <- function(Y, id=NULL, weight=NULL, sort=NULL, Dom=NULL,
                  var_nams <- do.call(paste, as.list(c(g, sep="__")))
                  ind <- as.integer(rowSums(Dom == Dom_agg[i,][ind0,]) == ncol(Dom))
                  
-                 rmpgapl <- lapply(1:nrow(period1_agg), function(j) {
+                 rmpgapl <- lapply(1 : nrow(period1_agg), function(j) {
                       if (!is.null(period)) { 
                                rown <- cbind(period_agg[j], Dom_agg[i])
                                setkeyv(rown, names(rown))
                                rown2 <- copy(rown)
-                               rown <- merge(rown, quantile, all.x=TRUE)
+                               rown <- merge(rown, quantile, all.x = TRUE)
                           } else { rown <- quantile
                                    rown2 <- Dom_agg[i] }
 
                        indj <- (rowSums(period1 == period1_agg[j,][ind0,]) == ncol(period1))
 
-                       rmpgap_l <- linrmpgCalc(inco=Y[indj],
-                                               ids=rmpgap_id[indj],
-                                               wght=weight[indj],
-                                               sort=sort[indj],
-                                               ind=ind[indj],
-                                               percentag=p,
-                                               order_quants=order_quant,
-                                               quant_val=rown[["quantile"]]) 
+                       rmpgap_l <- linrmpgCalc(inco = Y[indj],
+                                               ids = rmpgap_id[indj],
+                                               wght = weight[indj],
+                                               sort = sort[indj],
+                                               ind = ind[indj],
+                                               percentag = p,
+                                               order_quants = order_quant,
+                                               quant_val = rown[["quantile"]]) 
 
-                      list(rmpgap=data.table(rown2, rmpgap=rmpgap_l$rmpgap),
-                           lin=rmpgap_l$lin)
+                      list(rmpgap = data.table(rown2, rmpgap = rmpgap_l$rmpgap),
+                           lin = rmpgap_l$lin)
                  })
 
               rmpgaps <- rbindlist(lapply(rmpgapl, function(x) x[[1]]))
               rmpgaplin <- rbindlist(lapply(rmpgapl, function(x) x[[2]]))
 
               setnames(rmpgaplin, names(rmpgaplin), c(names(rmpgap_id), var_nams))
-              rmpgap_m <- merge(rmpgap_m, rmpgaplin, all.x=TRUE, by=names(rmpgap_id))
+              rmpgap_m <- merge(rmpgap_m, rmpgaplin, all.x = TRUE, by = names(rmpgap_id))
               rmpgap_v <- rbind(rmpgap_v, rmpgaps) 
            }
- } else {rmpgap_l <- lapply(1:nrow(period1_agg), function(j) {
+ } else {rmpgap_l <- lapply(1 : nrow(period1_agg), function(j) {
                            if (!is.null(period)) { 
                                          rown <- period_agg[j]
                                          setkeyv(rown, names(rown))
-                                         rown <- merge(rown, quantile, all.x=TRUE)
+                                         rown <- merge(rown, quantile, all.x = TRUE)
                                        } else rown <- quantile
                            indj <- (rowSums(period1 == period1_agg[j,][ind0,]) == ncol(period1))
       
-                           rmpgapl <- linrmpgCalc(inco=Y[indj], ids=rmpgap_id[indj],
-                                                  wght=weight[indj], sort=sort[indj],
-                                                  ind=ind0[indj], percentag=p,
-                                                  order_quants=order_quant,
-                                                  quant_val=rown[["quantile"]])  
+                           rmpgapl <- linrmpgCalc(inco = Y[indj],
+                                                  ids = rmpgap_id[indj],
+                                                  wght = weight[indj],
+                                                  sort = sort[indj],
+                                                  ind = ind0[indj],
+                                                  percentag = p,
+                                                  order_quants = order_quant,
+                                                  quant_val = rown[["quantile"]])  
                            if (!is.null(period)) {
-                               rmpgap_v <- data.table(period_agg[j], rmpgap=rmpgapl$rmpgap)
-                             } else rmpgap_v <- data.table(rmpgap=rmpgapl$rmpgap)
-                          list(rmpgap_v=rmpgap_v, lin=rmpgapl$lin)
+                               rmpgap_v <- data.table(period_agg[j], rmpgap = rmpgapl$rmpgap)
+                             } else rmpgap_v <- data.table(rmpgap = rmpgapl$rmpgap)
+                          list(rmpgap_v = rmpgap_v, lin = rmpgapl$lin)
                        })
                rmpgap_v <- rbindlist(lapply(rmpgap_l, function(x) x[[1]]))
                rmpgap_m <- rbindlist(lapply(rmpgap_l, function(x) x[[2]]))
@@ -206,69 +213,73 @@ linrmpg <- function(Y, id=NULL, weight=NULL, sort=NULL, Dom=NULL,
          }
    rmpgap_m[is.na(rmpgap_m)] <- 0
    setkeyv(rmpgap_m, names(rmpgap_id))
-   return(list(quantile=quantile, threshold=threshold, value=rmpgap_v, lin=rmpgap_m)) 
+   return(list(quantile = quantile, threshold = threshold, value = rmpgap_v, lin = rmpgap_m)) 
 }
 
 ## workhorse
 linrmpgCalc <- function(inco, ids, wght, sort, ind, percentag, order_quants, quant_val) {
     wt <- ind*wght   
-    thres_val <- percentag/100 * quant_val
+    thres_val <- percentag / 100 * quant_val
     N0 <- sum(wght)                # Estimated whole population size
     N <- sum(wt)                # Estimated (sub)population size
-    poor <- (inco<=thres_val)*ind
+    poor <- (inco <= thres_val) * ind
 
-    inc1 <- inco[poor==1]
-    wght1 <- wght[poor==1]
-    sort1 <- sort[poor==1]
+    inc1 <- inco[poor == 1]
+    wght1 <- wght[poor == 1]
+    sort1 <- sort[poor == 1]
 
-    rate_val <- sum(wt*poor)/N  # Estimated poverty rate
-    rate_val_pr <- 100*rate_val  # Estimated poverty rate
+    rate_val <- sum(wt * poor) / N  # Estimated poverty rate
+    rate_val_pr <- 100 * rate_val  # Estimated poverty rate
  
-    poor_people_median <- incPercentile(Y=inc1, weights=wght1,
-                                        sort=sort1, Dom=NULL,
-                                        period=NULL, k=order_quants,
-                                        dataset=NULL)
+    poor_people_median <- incPercentile(Y = inc1,
+                                        weights = wght1,
+                                        sort=sort1,
+                                        Dom = NULL,
+                                        period = NULL,
+                                        k = order_quants,
+                                        dataset = NULL)
     poor_people_median <- poor_people_median[[paste0("x", order_quants)]]
+
 #*************************************************************************************
  #**          LINEARIZATION OF THE MEDIAN INCOME BELOW THE POVERTY THRESHOLD         **
  #*************************************************************************************
-    h <- sqrt((sum(wght*inco*inco)-sum(wght*inco)*sum(wght*inco)/sum(wght))/sum(wght))/exp(0.2*log(sum(wght))) 
+    h <- sqrt((sum(wght * inco * inco) - sum(wght * inco) * sum(wght * inco) / sum(wght)) / sum(wght)) / exp(0.2 * log(sum(wght))) 
    # h=S/N^(1/5)
  
  #--------------------------------------------------
  #----- LINEARIZATION OF THE POVERTY THRESHOLD -----
  #--------------------------------------------------
-    u1 <- (quant_val-inco)/h
-    vect_f1 <- exp(-(u1^2)/2)/sqrt(2*pi)
-    f_quant1 <- sum(vect_f1*wght)/(N0*h) 
+    u1 <- (quant_val - inco) / h
+    vect_f1 <- exp(-(u1^2) / 2)/sqrt(2 * pi)
+    f_quant1 <- sum(vect_f1 * wght)/(N0 * h) 
 
-    lin_thres <- -(percentag/100)*(1/N0)*((inco<=quant_val)-order_quants/100)/f_quant1
+    lin_thres <- - (percentag / 100) * (1 / N0) * ((inco <= quant_val) - order_quants / 100) / f_quant1
  # ---------------------------------------------
  # ----- LINEARIZATION OF THE POVERTY RATE -----
  # ---------------------------------------------
-    u2 <- (thres_val-inco)/h
-    vect_f2 <- exp(-(u2^2)/2)/sqrt(2*pi)
-    f_quant2 <- sum(vect_f2*wt)/(N*h) 
+    u2 <- (thres_val - inco) / h
+    vect_f2 <- exp(-(u2^2) / 2) / sqrt(2 * pi)
+    f_quant2 <- sum(vect_f2 * wt) / (N * h) 
 
-    lin_rate <- (1/N)*ind*((inco<=thres_val)-rate_val)+f_quant2*lin_thres
+    lin_rate <- (1 / N) * ind * ((inco <= thres_val) - rate_val) + f_quant2 * lin_thres
  # --------------------------------------------------------
  # ----- LINEARIZATION OF POOR PEOPLE'S MEDIAN INCOME -----
  # --------------------------------------------------------
-     u3 <- (poor_people_median-inco)/h
-     vect_f3 <- exp(-(u3^2)/2)/sqrt(2*pi)
-     f_quant3 <- sum(vect_f3*wt)/(N*h) 
+     u3 <- (poor_people_median - inco) / h
+     vect_f3 <- exp(-(u3^2) / 2) / sqrt(2 * pi)
+     f_quant3 <- sum(vect_f3 * wt) / (N * h) 
 
-     lin_median <- (0.5*lin_rate-(1/N)*ind*((inco<=poor_people_median)-0.5*rate_val))/f_quant3
+     lin_median <- (0.5 * lin_rate - (1 / N) * ind * ((inco <= poor_people_median) - 0.5 * rate_val)) / f_quant3
 
  #*****************************************************************************************
  #                   LINEARIZED VARIABLE OF THE RELATIVE MEDIAN GAP (IN %)                *
  #*****************************************************************************************
-     lin_gap <- 100*(poor_people_median*lin_thres/(thres_val*thres_val)-lin_median/thres_val)
+     lin_gap <- 100 * (poor_people_median * lin_thres / (thres_val * thres_val) - lin_median / thres_val)
      
-     rmpgap <- 100 - 100*poor_people_median/thres_val
+     rmpgap <- 100 - 100 * poor_people_median / thres_val
 
      lin_id <- data.table(ids, lin_gap)
 
-     return(list(rmpgap=rmpgap, lin=lin_id))
+     return(list(rmpgap = rmpgap, lin = lin_id))
 }
 
