@@ -1,4 +1,4 @@
-transpos <- function(variable, period_NULL, valnames, pernames, variabname=NULL) {
+transpos <- function(variable, period_NULL, valnames, pernames, variabname = NULL) {
         if (period_NULL) {dati <- data.table(nv=names(variable), t(variable))
                           setnames(dati, names(dati), c("variable", valnames))
                  } else { dati <- melt(variable, id=c(pernames))
@@ -19,7 +19,7 @@ vardom <- function(Y, H, PSU, w_final,
                    PSU_sort=NULL, 
                    N_h = NULL,
                    fh_zero=FALSE,
-                   PSU_level=TRUE,
+                   PSU_level = TRUE,
                    Z = NULL,
                    X = NULL,
                    ind_gr = NULL,
@@ -27,7 +27,7 @@ vardom <- function(Y, H, PSU, w_final,
                    q = NULL,
                    dataset = NULL, 
                    confidence = .95,
-                   percentratio=1,
+                   percentratio = 1,
                    outp_lin = FALSE,
                    outp_res = FALSE) {
  
@@ -42,48 +42,48 @@ vardom <- function(Y, H, PSU, w_final,
 
   if(!is.null(dataset)) {
       dataset <- data.table(dataset)
-      if (min(Y %in% names(dataset))!=1) stop("'Y' does not exist in 'dataset'!")
-      if (min(Y %in% names(dataset))==1) { Y <- dataset[, Y, with=FALSE] }
+      if (min(Y %in% names(dataset)) != 1) stop("'Y' does not exist in 'dataset'!")
+      if (min(Y %in% names(dataset)) == 1) { Y <- dataset[, Y, with = FALSE] }
       if(!is.null(id)) {
-          if (min(id %in% names(dataset))!=1) stop("'id' does not exist in 'dataset'!")
-          if (min(id %in% names(dataset))==1) id <- dataset[, id, with=FALSE] }
+          if (min(id %in% names(dataset)) != 1) stop("'id' does not exist in 'dataset'!")
+          if (min(id %in% names(dataset)) == 1) id <- dataset[, id, with = FALSE] }
       if(!is.null(H)) {
-          if (min(H %in% names(dataset))!=1) stop("'H' does not exist in 'dataset'!")
-          if (min(H %in% names(dataset))==1) H <- dataset[, H, with=FALSE] }
+          if (min(H %in% names(dataset)) != 1) stop("'H' does not exist in 'dataset'!")
+          if (min(H %in% names(dataset)) == 1) H <- dataset[, H, with = FALSE] }
       if(!is.null(PSU)) {
-          if (min(PSU %in% names(dataset))!=1) stop("'PSU' does not exist in 'dataset'!")
-          if (min(PSU %in% names(dataset))==1) PSU <- dataset[, PSU, with=FALSE] }
+          if (min(PSU %in% names(dataset)) != 1) stop("'PSU' does not exist in 'dataset'!")
+          if (min(PSU %in% names(dataset)) == 1) PSU <- dataset[, PSU, with = FALSE] }
       if(!is.null(w_final)) {
-          if (min(w_final %in% names(dataset))!=1) stop("'w_final' does not exist in 'dataset'!")
-          if (min(w_final %in% names(dataset))==1) w_final <- dataset[, w_final, with=FALSE] }
+          if (min(w_final %in% names(dataset)) != 1) stop("'w_final' does not exist in 'dataset'!")
+          if (min(w_final %in% names(dataset)) == 1) w_final <- dataset[, w_final, with = FALSE] }
       if(!is.null(Z)) {
-          if (min(Z %in% names(dataset))!=1) stop("'Z' does not exist in 'dataset'!")
-          if (min(Z %in% names(dataset))==1) Z <- dataset[, Z, with=FALSE] }
+          if (min(Z %in% names(dataset)) != 1) stop("'Z' does not exist in 'dataset'!")
+          if (min(Z %in% names(dataset)) == 1) Z <- dataset[, Z, with = FALSE] }
       if (!is.null(period)) {
-           if (min(period %in% names(dataset))!=1) stop("'period' does not exist in 'dataset'!")
-           if (min(period %in% names(dataset))==1) period <- dataset[, period, with=FALSE] } 
+           if (min(period %in% names(dataset)) != 1) stop("'period' does not exist in 'dataset'!")
+           if (min(period %in% names(dataset)) == 1) period <- dataset[, period, with = FALSE] } 
       if(!is.null(X)) {
-          if (min(X %in% names(dataset))!=1) stop("'X' does not exist in 'dataset'!")
-          if (min(X %in% names(dataset))==1) X <- dataset[, X, with=FALSE] }
+          if (min(X %in% names(dataset)) != 1) stop("'X' does not exist in 'dataset'!")
+          if (min(X %in% names(dataset)) == 1) X <- dataset[, X, with = FALSE] }
       if(!is.null(ind_gr)) {
-          if (min(ind_gr %in% names(dataset))!=1) stop("'ind_gr' does not exist in 'dataset'!")
-          if (min(ind_gr %in% names(dataset))==1) ind_gr <- dataset[, ind_gr, with=FALSE] } 
+          if (min(ind_gr %in% names(dataset)) != 1) stop("'ind_gr' does not exist in 'dataset'!")
+          if (min(ind_gr %in% names(dataset)) == 1) ind_gr <- dataset[, ind_gr, with = FALSE] } 
       if(!is.null(g)) {
-          if (min(g %in% names(dataset))!=1) stop("'g' does not exist in 'dataset'!")
-          if (min(g %in% names(dataset))==1) g <- dataset[, g, with=FALSE] }
+          if (min(g %in% names(dataset)) != 1) stop("'g' does not exist in 'dataset'!")
+          if (min(g %in% names(dataset)) == 1) g <- dataset[, g, with = FALSE] }
       if(!is.null(q)) {
-          if (min(q %in% names(dataset))!=1) stop("'q' does not exist in 'dataset'!") 
-          if (min(q %in% names(dataset))==1) q <- dataset[, q, with=FALSE] } 
+          if (min(q %in% names(dataset)) != 1) stop("'q' does not exist in 'dataset'!") 
+          if (min(q %in% names(dataset)) == 1) q <- dataset[, q, with = FALSE] } 
       if (!is.null(Dom)) {
-          if (min(Dom %in% names(dataset))!=1) stop("'Dom' does not exist in 'dataset'!")
-          if (min(Dom %in% names(dataset))==1) Dom <- dataset[, Dom, with=FALSE] } 
+          if (min(Dom %in% names(dataset)) != 1) stop("'Dom' does not exist in 'dataset'!")
+          if (min(Dom %in% names(dataset)) == 1) Dom <- dataset[, Dom, with = FALSE] } 
        if (!is.null(PSU_sort)) {
-            if (min(PSU_sort %in% names(dataset))!=1) stop("'PSU_sort' does not exist in 'dataset'!")
-            if (min(PSU_sort %in% names(dataset))==1) PSU_sort <- dataset[, PSU_sort, with=FALSE] }  
+            if (min(PSU_sort %in% names(dataset)) != 1) stop("'PSU_sort' does not exist in 'dataset'!")
+            if (min(PSU_sort %in% names(dataset)) == 1) PSU_sort <- dataset[, PSU_sort, with = FALSE] }  
      }
 
   # Y
-  Y <- data.table(Y, check.names=TRUE)
+  Y <- data.table(Y, check.names = TRUE)
   n <- nrow(Y)
   m <- ncol(Y)
   if (any(is.na(Y))) stop("'Y' has missing values")
@@ -95,15 +95,15 @@ vardom <- function(Y, H, PSU, w_final,
   H <- data.table(H)
   if (nrow(H) != n) stop("'H' length must be equal with 'Y' row count")
   if (ncol(H) != 1) stop("'H' must be 1 column data.frame, matrix, data.table")
-  if (any(is.na(H))) stop("'H' has missing values")
   if (is.null(names(H))) stop("'H' must have column names")
-  H[, (names(H)):=lapply(.SD, as.character)]
+  H[, (names(H)) := lapply(.SD, as.character)]
+  if (any(is.na(H))) stop("'H' has missing values")
   
   # PSU
   PSU <- data.table(PSU)
   if (nrow(PSU) != n) stop("'PSU' length must be equal with 'Y' row count")
   if (ncol(PSU) != 1) stop("'PSU' has more than 1 column")
-  PSU[, (names(PSU)):=lapply(.SD, as.character)]
+  PSU[, (names(PSU)) := lapply(.SD, as.character)]
   if (any(is.na(PSU))) stop("'PSU' has missing values")
 
   # w_final 
@@ -121,7 +121,7 @@ vardom <- function(Y, H, PSU, w_final,
                 stop("'period' are duplicate column names: ", 
                      paste(names(period)[duplicated(names(period))], collapse = ","))
       if (nrow(period) != n) stop("'period' must be the same length as 'Y'")
-      period[, (names(period)):=lapply(.SD, as.character)]
+      period[, (names(period)) := lapply(.SD, as.character)]
       if(any(is.na(period))) stop("'period' has missing values")
   } 
   np <- sum(ncol(period))
@@ -137,18 +137,18 @@ vardom <- function(Y, H, PSU, w_final,
 
           psuag <- data.table(PSU, PSU_sort)
           if (!is.null(period)) hpY <- data.table(period, psuag)
-          psuag <- psuag[,.N, by=names(psuag)][,N:=NULL]
+          psuag <- psuag[,.N, by=names(psuag)][,N := NULL]
           psuag <- psuag[,.N, by=c(names(period), names(PSU))]
           if (nrow(psuag[N>1])>0) stop("'PSU_sort' must be equal for each 'PSU'")
   }
 
   # id
-  if (is.null(id)) id <- 1:n
+  if (is.null(id)) id <- 1 : n
   id <- data.table(id)
   if (any(is.na(id))) stop("'id' has missing values")
   if (ncol(id) != 1) stop("'id' must be 1 column data.frame, matrix, data.table")
   if (nrow(id) != n) stop("'id' length must be equal with 'Y' row count")
-  if (is.null(names(id))||(names(id)=="id")) setnames(id,names(id),"ID")
+  if (is.null(names(id))||(names(id) == "id")) setnames(id,names(id),"ID")
   if (is.null(period)){ if (any(duplicated(id))) stop("'id' are duplicate values") 
                        } else {dd <- data.table(period, id)
                                   if (any(duplicated(dd, by=names(dd)))) stop("'id' by period are duplicate values")
@@ -158,25 +158,25 @@ vardom <- function(Y, H, PSU, w_final,
   # N_h
   if (!is.null(N_h)) {
       N_h <- data.table(N_h)
-      if (ncol(N_h) != np+2) stop(paste0("'N_h' should be ",toString(np+2)," columns"))
+      if (ncol(N_h) != np+2) stop(paste0("'N_h' should be ", np + 2," columns"))
       if (!is.numeric(N_h[[ncol(N_h)]])) stop("The last column of 'N_h' should be numeric")
       if (any(is.na(N_h))) stop("'N_h' has missing values") 
       if (is.null(names(N_h))) stop("'N_h' must have column names")
-      if (all(names(H) %in% names(N_h))) {N_h[, (names(H)):=lapply(.SD, as.character), .SDcols=names(H)]
+      if (all(names(H) %in% names(N_h))) {N_h[, (names(H)) := as.character(get(names(H)))]
              } else stop("All strata titles of 'H' have not in 'N_h'")
       if (is.null(period)) {
              if (names(H) != names(N_h)[1]) stop("Strata titles for 'H' and 'N_h' is not equal")
              if (any(is.na(merge(unique(H), N_h, by=names(H), all.x = TRUE)))) stop("'N_h' is not defined for all strata")
-             if (any(duplicated(N_h[, head(names(N_h),-1), with=F]))) stop("Strata values for 'N_h' must be unique")
+             if (any(duplicated(N_h[, head(names(N_h), -1), with = FALSE]))) stop("Strata values for 'N_h' must be unique")
        } else { pH <- data.table(period, H)
-                if (any(names(pH) != names(N_h)[c(1:(1+np))])) stop("Strata titles for 'period' with 'H' and 'N_h' is not equal")
+                if (any(names(pH) != names(N_h)[c(1 : (1 + np))])) stop("Strata titles for 'period' with 'H' and 'N_h' is not equal")
                 nperH <- names(period)
-                N_h[, (nperH):=as.character(get(nperH))]
-                if (any(is.na(merge(unique(pH), N_h, by=names(pH), all.x=TRUE)))) stop("'N_h' is not defined for all strata and periods")
-                if (any(duplicated(N_h[, head(names(N_h),-1), with=FALSE]))) stop("Strata values for 'N_h' must be unique in all periods")
+                N_h[, (nperH) := as.character(get(nperH))]
+                if (any(is.na(merge(unique(pH), N_h, by = names(pH), all.x = TRUE)))) stop("'N_h' is not defined for all strata and periods")
+                if (any(duplicated(N_h[, head(names(N_h), -1), with = FALSE]))) stop("Strata values for 'N_h' must be unique in all periods")
                 pH <- NULL
      }
-    setkeyv(N_h, names(N_h)[c(1:(1+np))])
+    setkeyv(N_h, names(N_h)[c(1 : (1 + np))])
   }
 
   # Dom
@@ -189,7 +189,7 @@ vardom <- function(Y, H, PSU, w_final,
                  paste(names(Dom)[duplicated(names(Dom))], collapse = ","))
     if (nrow(Dom) != n) stop("'Dom' and 'Y' must be equal row count")
     if (is.null(namesDom)) stop("'Dom' must have column names")
-    Dom[, (namesDom):=lapply(.SD, as.character)]
+    Dom[, (namesDom) := lapply(.SD, as.character)]
     if (any(is.na(Dom))) stop("'Dom' has missing values")
     if (any(grepl("__", names(Dom)))) stop("'Dom' is not allowed column names with '__'")
   }
@@ -207,7 +207,7 @@ vardom <- function(Y, H, PSU, w_final,
       
   # X
   if (!is.null(X)) {
-    X <- data.table(X, check.names=TRUE)
+    X <- data.table(X, check.names = TRUE)
     if (!all(sapply(X, is.numeric))) stop("'X' must be numeric values")
     if (nrow(X) != n) stop("'X' and 'Y' have different row count")
   }
@@ -223,38 +223,38 @@ vardom <- function(Y, H, PSU, w_final,
 
   # X
   if (!is.null(X)) {
-       X1 <- data.table(X, check.names=TRUE)
+       X1 <- data.table(X, check.names = TRUE)
        nX1 <- names(X1)
        ind_gr1 <- copy(ind_gr) 
-       if (!is.null(period)) ind_gr1 <- data.table(period, ind_gr1, check.names=TRUE)
+       if (!is.null(period)) ind_gr1 <- data.table(period, ind_gr1, check.names = TRUE)
        X2 <- data.table(ind_gr1, X1)
        X1 <- X2[, .N, keyby=names(ind_gr1)][[ncol(ind_gr1)+1]]
        X2 <- X2[,lapply(.SD, function(x) sum(!is.na(x))), keyby=names(ind_gr1), .SDcols=nX1]
        X2 <- X2[, !(names(X2) %in% names(ind_gr1)), with=F]
-       if (!all(X2==0 | X1==X2)) stop("X has missing values")
+       if (!all(X2 == 0 | X1 == X2)) stop("X has missing values")
        ind_gr1 <- nX1 <- X1 <- X2 <- NULL
    }
 
   # g
   if (!is.null(X)) {
-    if (is.null(class(g)) | all(class(g)=="function")) stop("'g' must be numerical")
+    if (is.null(class(g)) | all(class(g) == "function")) stop("'g' must be numerical")
     g <- data.frame(g)
     if (nrow(g) != nrow(X)) stop("'g' length must be equal with 'X' row count")
     if (ncol(g) != 1) stop("'g' must be 1 column data.frame, matrix, data.table")
-    g <- g[,1]
+    g <- g[, 1]
     if (!is.numeric(g)) stop("'g' must be numeric")
     if (any(is.na(g))) stop("'g' has missing values")
-    if (any(g == 0)) stop("'g' value can not be 0")
+    if (any(g  ==  0)) stop("'g' value can not be 0")
    }
     
   # q
   if (!is.null(X)) {
     if (is.null(q))  q <- rep(1, nrow(X))
-    if (is.null(class(q)) | all(class(q)=="function")) stop("'q' must be numerical")
+    if (is.null(class(q)) | all(class(q) == "function")) stop("'q' must be numerical")
     q <- data.frame(q)
     if (nrow(q) != nrow(X)) stop("'q' length must be equal with 'X' row count")
     if (ncol(q) != 1) stop("'q' must be 1 column data.frame, matrix, data.table")
-    q <- q[,1]
+    q <- q[, 1]
     if (!is.numeric(q)) stop("'q' must be numeric")
     if (any(is.na(q))) stop("'q' has missing values")
     if (any(is.infinite(q))) stop("'q' value can not be infinite")
@@ -267,22 +267,22 @@ vardom <- function(Y, H, PSU, w_final,
   n_nonzero <- copy(Y1)
   if (!is.null(period)){ n_nonzero <- data.table(period, n_nonzero) 
                          n_nonzero <- n_nonzero[, lapply(.SD, function(x) 
-                                                          sum(as.integer(abs(x)> .Machine$double.eps))),
-                                                          keyby=names(period),
+                                                          sum(as.integer(abs(x) > .Machine$double.eps))),
+                                                          keyby = names(period),
                                                          .SDcols = names(Y1)]
                   } else n_nonzero <- n_nonzero[, lapply(.SD, function(x) 
-                                                          sum(as.integer(abs(x)> .Machine$double.eps))),
+                                                          sum(as.integer(abs(x) > .Machine$double.eps))),
                                                          .SDcols = names(Y1)]
 
   sar_nr <- respondent_count <- pop_size <- NULL
-  nhs <- data.table(respondent_count=1, pop_size=w_final)
+  nhs <- data.table(respondent_count = 1, pop_size = w_final)
   if (!is.null(period)) nhs <- data.table(period, nhs)
   if (!is.null(Dom)) nhs <- data.table(Dom, nhs)
-  if (!is.null(c(Dom, period))) {nhs <- nhs[, lapply(.SD, sum, na.rm=TRUE),
-                                                      keyby=eval(names(nhs)[0:1-ncol(nhs)]),
-                                                     .SDcols=c("respondent_count", "pop_size")]
-                          } else nhs <- nhs[, lapply(.SD, sum, na.rm=TRUE),
-                                                     .SDcols=c("respondent_count", "pop_size")]
+  if (!is.null(c(Dom, period))) {nhs <- nhs[, lapply(.SD, sum, na.rm = TRUE),
+                                                      keyby = eval(names(nhs)[0 : 1 - ncol(nhs)]),
+                                                     .SDcols = c("respondent_count", "pop_size")]
+                          } else nhs <- nhs[, lapply(.SD, sum, na.rm = TRUE),
+                                                     .SDcols = c("respondent_count", "pop_size")]
 
   # Design weights
   if (!is.null(X)) w_design <- w_final / g else w_design <- w_final
@@ -301,16 +301,16 @@ vardom <- function(Y, H, PSU, w_final,
   if (!is.null(Z)) {
     if (!is.null(Dom)) Z1 <- domain(Z, Dom) else Z1 <- Z
     if (is.null(period)) {
-          Y2 <- lin.ratio(Y1, Z1, w_final, Dom=NULL, percentratio=percentratio)
+          Y2 <- lin.ratio(Y1, Z1, w_final, Dom = NULL, percentratio = percentratio)
         } else {
             periodap <- do.call("paste", c(as.list(period), sep="_"))
             lin1 <- lapply(split(Y1[, .I], periodap), function(i)
-                            data.table(sar_nr=i, 
+                            data.table(sar_nr = i, 
                                    lin.ratio(Y1[i], Z1[i], w_final[i],
-                                     Dom=NULL, percentratio=percentratio)))
+                                             Dom=NULL, percentratio = percentratio)))
             Y2 <- rbindlist(lin1)
             setkeyv(Y2, "sar_nr")
-            Y2[, sar_nr:=NULL]
+            Y2[, sar_nr := NULL]
         }
     if (any(is.na(Y2))) print("Results are calculated, but there are cases where Z = 0")
     if (outp_lin) linratio_outp <- data.table(idper, PSU, Y2) 
@@ -326,11 +326,14 @@ vardom <- function(Y, H, PSU, w_final,
         ind_gr <- do.call("paste", c(as.list(ind_gr), sep="_"))
 
         lin1 <- lapply(split(Y2[,.I], ind_gr), function(i) 
-                        data.table(sar_nr=i, residual_est(Y=Y2[i],
-                                    X=X[i], weight=w_design[i], q=q[i])))
+                        data.table(sar_nr = i,
+                                   residual_est(Y = Y2[i],                                   
+                                                X = X[i],
+                                                weight = w_design[i],
+                                                q = q[i])))
         Y3 <- rbindlist(lin1)
         setkeyv(Y3, "sar_nr")
-        Y3[, sar_nr:=NULL]
+        Y3[, sar_nr := NULL]
         if (outp_res) res_outp <- data.table(idper, PSU, Y3)
   } else Y3 <- Y2
   
@@ -341,12 +344,12 @@ vardom <- function(Y, H, PSU, w_final,
                           PSU_sort = PSU_sort,
                           period = period,
                           dataset = NULL,
-                          msg="Current variance estimation")
+                          msg = "Current variance estimation")
   var_est <- transpos(var_est, is.null(period), "var_est", names(period))
   all_result <- var_est
     
   n_nonzero <- transpos(n_nonzero, is.null(period), "n_nonzero", names(period))
-  all_result <- merge(all_result, n_nonzero, all=TRUE)
+  all_result <- merge(all_result, n_nonzero, all = TRUE)
  
   # Variance of HT estimator under current design
   var_cur_HT <- variance_est(Y = Y2, H = H, PSU = PSU,
@@ -356,9 +359,9 @@ vardom <- function(Y, H, PSU, w_final,
                              PSU_sort = PSU_sort,
                              period = period,
                              dataset = NULL,
-                             msg="Variance of HT estimator under current design")
+                             msg = "Variance of HT estimator under current design")
   var_cur_HT <- transpos(var_cur_HT, is.null(period), "var_cur_HT", names(period))
-  all_result <- merge(all_result, var_cur_HT, all=TRUE)
+  all_result <- merge(all_result, var_cur_HT, all = TRUE)
   n_nonzero <- var_est <- var_cur_HT <- NULL
   
   # Variance of HT estimator under SRS
@@ -371,7 +374,7 @@ vardom <- function(Y, H, PSU, w_final,
            period_agg <- unique(period)
            lin1 <- lapply(1:nrow(period_agg), function(i) {
                           per <- period_agg[i,][rep(1, nrow(Y2)),]
-                          ind <- (rowSums(per == period) == ncol(period))
+                          ind <- (rowSums(per  ==  period)  ==  ncol(period))
                           varsrs <- var_srs(Y = Y2[ind], w = w_design[ind])
                           varsca <- var_srs(Y = Y2[ind], w = w_final[ind])
                           list(S2p = data.table(period_agg[i,], varsrs$S2p),
@@ -383,11 +386,11 @@ vardom <- function(Y, H, PSU, w_final,
            S2_y_ca <- rbindlist(lapply(lin1, function(x) x[[3]]))           
       }
   var_srs_HT <- transpos(var_srs_HT, is.null(period), "var_srs_HT", names(period))
-  all_result <- merge(all_result, var_srs_HT, all=TRUE)
+  all_result <- merge(all_result, var_srs_HT, all = TRUE)
   S2_y_HT <- transpos(S2_y_HT, is.null(period), "S2_y_HT", names(period))
-  all_result <- merge(all_result, S2_y_HT, all=TRUE)
+  all_result <- merge(all_result, S2_y_HT, all = TRUE)
   S2_y_ca <- transpos(S2_y_ca, is.null(period), "S2_y_ca", names(period))
-  all_result <- merge(all_result, S2_y_ca, all=TRUE)
+  all_result <- merge(all_result, S2_y_ca, all = TRUE)
 
   # Variance of calibrated estimator under SRS
   if (is.null(period)) {
@@ -398,7 +401,7 @@ vardom <- function(Y, H, PSU, w_final,
            period_agg <- unique(period)
            lin1 <- lapply(1:nrow(period_agg), function(i) {
                           per <- period_agg[i,][rep(1, nrow(Y2)),]
-                          ind <- (rowSums(per == period) == ncol(period))
+                          ind <- (rowSums(per  ==  period)  ==  ncol(period))
                           varsres <- var_srs(Y = Y3[ind], w = w_final[ind])
                           list(S2p = data.table(period_agg[i,], varsres$S2p),
                                varsrs = data.table(period_agg[i,], varsres$varsrs))
@@ -408,9 +411,9 @@ vardom <- function(Y, H, PSU, w_final,
         }
   Y3 <- NULL
   var_srs_ca <- transpos(var_srs_ca, is.null(period), "var_srs_ca", names(period), "variable")
-  all_result <- merge(all_result, var_srs_ca, all=TRUE)
+  all_result <- merge(all_result, var_srs_ca, all = TRUE)
   S2_res <- transpos(S2_res, is.null(period), "S2_res", names(period), "variable")
-  all_result <- merge(all_result, S2_res, all=TRUE)
+  all_result <- merge(all_result, S2_res, all = TRUE)
   Y2 <- S2_y_HT <- S2_y_ca <- S2_res <- var_srs_HT <- var_srs_ca <- NULL
 
   # Total estimation
@@ -419,75 +422,68 @@ vardom <- function(Y, H, PSU, w_final,
   hY <- data.table(Y1 * w_final)
   if (is.null(period)) { Y_nov <- hY[, lapply(.SD, sum, na.rm = TRUE), .SDcols = names(Y1)]
                 } else { hY <- data.table(period, hY)
-                         Y_nov <- hY[, lapply(.SD, sum, na.rm = TRUE), keyby=names(period), .SDcols = names(Y1)]
+                         Y_nov <- hY[, lapply(.SD, sum, na.rm = TRUE), keyby = names(period), .SDcols = names(Y1)]
                        }
   Y_nov <- transpos(Y_nov, is.null(period), "Y_nov", names(period))
-  all_result <- merge(all_result, Y_nov, all=TRUE)
+  all_result <- merge(all_result, Y_nov, all = TRUE)
 
   if (!is.null(Z1)) {
-         YZnames <- data.table(variable=names(Y1), variableDZ=names(Z1))
-         setkeyv(YZnames, "variable")
-         setkeyv(all_result, "variable")
-         all_result <- merge(all_result, YZnames, all=TRUE)
+         YZnames <- data.table(variable = names(Y1), variableDZ = names(Z1))
+         all_result <- merge(all_result, YZnames, all = TRUE, by = "variable")
          
-         hZ <- data.table(Z1*w_final)
+         hZ <- data.table(Z1 * w_final)
          if (is.null(period)) { Z_nov <- hZ[, lapply(.SD, sum, na.rm = TRUE), .SDcols = names(Z1)]
                        } else { hZ <- data.table(period, hZ)
-                                Z_nov <- hZ[, lapply(.SD, sum, na.rm = T), keyby=names(period), .SDcols = names(Z1)]
+                                Z_nov <- hZ[, lapply(.SD, sum, na.rm = T), keyby = names(period), .SDcols = names(Z1)]
                               }
          Z_nov <- transpos(Z_nov, is.null(period), "Z_nov", names(period), "variableDZ")
-         setkeyv(all_result, c(names(period), "variableDZ"))
-         all_result <- merge(all_result, Z_nov, all=TRUE)
+         all_result <- merge(all_result, Z_nov, all = TRUE, by = "variableDZ")
       }
 
-  vars <- data.table(variable=names(Y1), nr_names=1:ncol(Y1))
-  setkey(vars, "variable")
-  setkey(all_result, "variable")
-  all_result <- merge(vars, all_result, all=TRUE)
+  vars <- data.table(variable = names(Y1), nr_names = 1 : ncol(Y1))
+  all_result <- merge(vars, all_result, all = TRUE, by = "variable")
 
   vars <- idper <- Y_nov <- NULL
   Z_nov <- hY <- hZ <- YZnames <- dati <- NULL                          
 
-  all_result[, estim:=Y_nov]
-  if (!is.null(all_result$Z_nov)) all_result[, estim:=Y_nov/Z_nov * percentratio] 
+  all_result[, estim := Y_nov]
+  if (!is.null(all_result$Z_nov)) all_result[, estim := Y_nov / Z_nov * percentratio] 
 
-  if (nrow(all_result[var_est < 0])>0) stop("Estimation of variance are negative!")
+  if (nrow(all_result[var_est < 0]) > 0) stop("Estimation of variance are negative!")
  
   # Design effect of sample design
-  all_result[, deff_sam:=var_cur_HT / var_srs_HT]
+  all_result[, deff_sam := var_cur_HT / var_srs_HT]
   
   # Design effect of estimator
-  all_result[, deff_est:= var_est / var_cur_HT]
+  all_result[, deff_est := var_est / var_cur_HT]
   
   # Overall effect of sample design and estimator
-  all_result[, deff:= deff_sam * deff_est]
+  all_result[, deff := deff_sam * deff_est]
 
-  all_result[, var_est2:=var_est]
-  all_result[xor(is.na(var_est2), var_est2 < 0), var_est2:=NA]
-  all_result[, se:=sqrt(var_est2)]
-  all_result[(estim!=0) & !is.nan(estim), rse:= se/estim]
-  all_result[estim==0 | is.nan(estim), rse:=NA]
-  all_result[, cv:= rse*100]
+  all_result[, var_est2 := var_est]
+  all_result[xor(is.na(var_est2), var_est2 < 0), var_est2 := NA]
+  all_result[, se := sqrt(var_est2)]
+  all_result[(estim != 0) & !is.nan(estim), rse := se / estim]
+  all_result[estim == 0 | is.nan(estim), rse := NA]
+  all_result[, cv := rse * 100]
 
-  tsad <- qnorm(0.5*(1+confidence))
-  all_result[, absolute_margin_of_error:= tsad*se]
-  all_result[, relative_margin_of_error:= tsad*cv]
-  all_result[, CI_lower:= estim - tsad*se]
-  all_result[, CI_upper:= estim + tsad*se]
+  tsad <- qnorm(0.5 * (1 + confidence))
+  all_result[, absolute_margin_of_error := tsad * se]
+  all_result[, relative_margin_of_error:= tsad * cv]
+  all_result[, CI_lower := estim - tsad * se]
+  all_result[, CI_upper := estim + tsad * se]
   
   setnames(all_result, c("variable", "var_est"), c("variableD", "var"))
   if (!is.null(all_result$Z_nov)) {
                        nosrZ <- all_result$variableDZ
                        nosrZ <- nosrZ[!duplicated(nosrZ)]
-                       nosrZ1 <- data.table(variableZ=t(data.frame(strsplit(nosrZ, "__")))[,c(1)])
-                       nosrZ <- data.table(variableDZ=nosrZ, nosrZ1)
-                       setkeyv(nosrZ, "variableDZ")
-                       setkeyv(all_result, "variableDZ")
-                       all_result <- merge(all_result, nosrZ)
+                       nosrZ1 <- data.table(variableZ = t(data.frame(strsplit(nosrZ, "__")))[, c(1)])
+                       nosrZ <- data.table(variableDZ = nosrZ, nosrZ1)
+                       all_result <- merge(all_result, nosrZ, by="variableDZ")
                        nosrZ <- nosrZ1 <- NULL
                     }
 
-  nosr <- data.table(variableD=all_result$variableD, t(data.frame(strsplit(all_result$variableD, "__"))))
+  nosr <- data.table(variableD = all_result$variableD, t(data.frame(strsplit(all_result$variableD, "__"))))
   nosr <- nosr[!duplicated(nosr)]
   nosr <- nosr[, lapply(nosr, as.character)]
   setnames(nosr, names(nosr)[2], "variable")
@@ -495,32 +491,32 @@ vardom <- function(Y, H, PSU, w_final,
   namesDom1 <- namesDom
   if (!is.null(Dom)) {
        setnames(nosr, names(nosr)[3:ncol(nosr)], paste0(namesDom, "_new"))
-       nhs[, (paste0(namesDom, "_new")):=lapply(namesDom, function(x) make.names(paste0(x,".", get(x))))]
+       nhs[, (paste0(namesDom, "_new")) := lapply(namesDom, function(x) make.names(paste0(x,".", get(x))))]
        namesDom1 <- paste0(namesDom, "_new")
     }
 
-  setkeyv(nosr, "variableD")
-  setkeyv(all_result, "variableD")
-  all_result <- merge(nosr, all_result)
+  all_result <- merge(nosr, all_result, by = "variableD")
   namesDom <- nosr <- NULL
   
   if (!is.null(all_result$Z_nov)) { 
-       all_result[, variable:=paste("R", get("variable"), get("variableZ"), sep="__")] }
-  setkeyv(all_result, c(namesDom1, names(period)))
-  setkeyv(nhs, c(namesDom1, names(period)))
+       all_result[, variable := paste("R", get("variable"), get("variableZ"), sep = "__")] }
 
-  if (!is.null(c(Dom, period))) { all_result <- merge(all_result, nhs, all=TRUE)
-                         } else { all_result[, respondent_count:=nhs$respondent_count]
-                                  all_result[, pop_size:=nhs$pop_size]} 
-
-  all_result[, n_eff:=ifelse(is.na(deff) | deff<.Machine$double.eps, NA, respondent_count/deff)]
-  variab <- c("respondent_count", "n_nonzero", "pop_size", "estim", "var", "se", 
-              "rse", "cv", "absolute_margin_of_error", "relative_margin_of_error",
-              "CI_lower", "CI_upper", "S2_y_HT", "S2_y_ca", "S2_res", "var_srs_HT",   
-              "var_cur_HT", "var_srs_ca", "deff_sam", "deff_est", "deff", "n_eff")
+  if (!is.null(c(Dom, period))) { all_result <- merge(all_result, nhs, 
+                                                      all = TRUE, by = c(namesDom1, names(period)))
+                         } else { all_result[, respondent_count := nhs$respondent_count]
+                                  all_result[, pop_size := nhs$pop_size]} 
 
+  all_result[, n_eff := ifelse(is.na(deff) | deff < .Machine$double.eps, NA, respondent_count / deff)]
+  variab <- c("respondent_count", "n_nonzero", "pop_size")
+  if (!is.null(all_result$Z_nov)) variab <- c(variab, "Y_nov", "Z_nov")
+  variab <- c(variab, "estim", "var", "se", "rse", "cv", 
+              "absolute_margin_of_error", "relative_margin_of_error",
+              "CI_lower", "CI_upper")
+  if (is.null(Dom))  variab <- c(variab, "S2_y_HT", "S2_y_ca", "S2_res") 
+  variab <- c(variab, "var_srs_HT",  "var_cur_HT", "var_srs_ca",
+              "deff_sam", "deff_est", "deff", "n_eff")
   setkeyv(all_result, c("nr_names", names(Dom), names(period)))
-  all_result <- all_result[, c("variable", names(Dom), names(period), variab), with=FALSE]
+  all_result <- all_result[, c("variable", names(Dom), names(period), variab), with = FALSE]
 
   list(lin_out = linratio_outp,
        res_out = res_outp,
